Welcome to Orange3 Single Cell Documentation
============================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/singlecelldatasets
   widgets/normalize
   widgets/scoregenes
   widgets/scorecells
   widgets/filter
   widgets/tsne
   widgets/louvain
